#
# spec file for package lirc (Version 0.8.4MACRO)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           lirc
BuildRequires:  alsa-devel xorg-x11-devel libftdi-devel
# for hw_atilibusb driver
%if 0%suse_version > 1020
BuildRequires:  libusb-devel
%else
BuildRequires:  libusb
%endif
%ifnarch s390 s390x
# for hw_i2cuser driver
%if 0%suse_version > 1010
BuildRequires:  linux-kernel-headers
%if 0%suse_version > 1030
# i2c-dev.h now moved to that package
BuildRequires:  i2c-tools
%endif
%endif
%endif
%if 0%suse_version > 1020
BuildRequires:  fdupes
%endif
Url:            http://www.lirc.org/
License:        GPL v2 or later
Group:          Hardware/Other
AutoReqProv:    on
Version:        0.8.5%{?snapshot:_%snapshot}
Release:        19.8
PreReq:         %fillup_prereq %insserv_prereq
Summary:        Tools for Infrared Receivers
Source0:        lirc-%{?snapshot}%{!?snapshot:%version}.tar.bz2
Source4:        rc.lirc
Source5:        sysconfig.lirc
Source6:        fix-remote-keys.pl
Source7:        http://linux.bytesex.org/v4l2/linux-input-layer-lircd.conf
Source8:        README.SUSE
Source9:        51-lirc.rules
#Patch0:       lirc-hw.diff
Patch1:         lirc-sockets-in-var.diff
Patch2:         imon2_conf.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       udev
Suggests:       lirc-kmp
Provides:       lirc-devel
Supplements:    lirc-kmp

%description
LIRC is a package that supports receiving and sending IR signals with
the most common IR remote controls. It contains a daemon that decodes
and sends IR signals, a mouse daemon that translates IR signals to
mouse movements, and a couple of user programs that allow you to
control your computer with a remote control.



%prep
%setup -q -n %{name}-%{?snapshot}%{!?snapshot:%version}
#%patch0 -p1 -b .hw
%patch1 -p1 -b .var
%patch2 -p1
cp %{SOURCE8} .
#find . -type d -name CVS -print0 | xargs -0 -- rm -rf
#find . -name .cvsignore  -print0 | xargs -0 -- rm -rf

%build
%if 0%suse_version < 1020
# XXX: hw_i2cuser doesn't build on sles10
sed -i -e 's/linux\/i2c-dev\.h/foobarblah.h/' configure.ac
%endif
%{?suse_update_config:%{suse_update_config -fl}}
autoreconf -vfi
PYTHON=/usr/bin/python \
CFLAGS="%{optflags}" ./configure \
	--prefix=%{_prefix}	\
	--mandir=%{_mandir}	\
	--libdir=%{_libdir}	\
	--sysconfdir=/etc	\
	--with-driver=userspace	\
	--with-port=0x3f8	\
	--with-irq=4		\
	--with-syslog
make -C daemons
make -C tools
make -C doc
chmod -R u+w remotes
chmod -R +r remotes
rm -rf remotes/*/.xvpics/
perl %{SOURCE6} remotes

%install
# lirc
make -C daemons  DESTDIR=%{buildroot} install
make -C tools    DESTDIR=%{buildroot} install
make -C doc      DESTDIR=%{buildroot} install
mkdir -p %{buildroot}/usr/share/lirc
cp -a remotes %{buildroot}/usr/share/lirc
cp -a %{SOURCE7} %{buildroot}/usr/share/lirc/remotes
install -d -m 755 %{buildroot}/dev
mkdir -p %{buildroot}/var/run/lirc
mkfifo %{buildroot}/var/run/lirc/lircm
chmod 600 %{buildroot}/var/run/lirc/*
# lircd init scripts
install -d -m 755	%{buildroot}/etc/init.d			\
			%{buildroot}/usr/sbin			\
			%{buildroot}/var/adm/fillup-templates
install -m 0755 %{SOURCE4} %{buildroot}/etc/init.d/lirc
ln -sf ../../etc/init.d/lirc %{buildroot}/usr/sbin/rclirc
install -m 0644 %{SOURCE5} %{buildroot}/var/adm/fillup-templates
#
# udev stuff
install -d -m 755 %{buildroot}/etc/udev/rules.d
install -d -m 755 %{buildroot}/sbin
install -m 644 %{SOURCE9} %{buildroot}/etc/udev/rules.d
find %{buildroot}/usr/share/lirc -perm +111 -type f -print0 | xargs -r -0 chmod a-x
#
# get rid of libtool file
rm -f %{buildroot}%{_libdir}/liblirc_client.la
#
# get rid of useless contrib stuff
rm contrib/lirc.*
%if 0%suse_version > 1020
%fdupes $RPM_BUILD_ROOT
%endif
#
# ghost file
install -D -m 644 /dev/null %{buildroot}/etc/lircd.conf
# hide python dependency
chmod 644 %{buildroot}%{_bindir}/pronto2lirc

%files
%defattr (-,root,root)
%doc ANNOUNCE AUTHORS COPYING ChangeLog NEWS README TODO
%doc README.SUSE
%doc doc/html doc/images doc/lirc.hwdb doc/lirc.css doc/irxevent.keys 
%doc contrib
%dir /usr/include/lirc
/usr/include/lirc/lirc_client.h
%{_libdir}/liblirc_client.*
#%attr (600,root,root) %dev(c,61,0) /dev/lirc	# => udev
%dir /var/run/lirc
/var/run/lirc/lircm
%attr(0755,root,root)/usr/bin/*
/usr/sbin/*
/usr/share/lirc
/etc/init.d/lirc
/var/adm/fillup-templates/sysconfig.lirc
%dir /etc/udev
%dir /etc/udev/rules.d
/etc/udev/rules.d/51-lirc.rules
%doc %_mandir/man1/*
%doc %_mandir/man8/*
%ghost %verify(not md5 size mtime) %config(noreplace,missingok) /etc/lircd.conf

%preun
%stop_on_removal lirc

%post
/sbin/ldconfig
%{fillup_and_insserv lirc}

%postun
/sbin/ldconfig
%restart_on_update lirc
%{insserv_cleanup}

%clean
rm -rf %{buildroot}

%changelog
* Wed Jul 08 2009 Carsten Schoene <cs@linux-administrator.com> - 0.8.5-18
- update to release 0.8.5
* Thu Nov 13 2008 lnussel@suse.de
- don't BuildRequire i2c-tools on s390 as it doesn't exist there
* Mon Oct 13 2008 lnussel@suse.de
- new version 0.8.4
  * added support for ITE8709 CIR port (Gregory Lardiere)
  * added pronto2lirc converter (Olavi Akerman)
  * support for include directive in lircd.conf
* Tue Aug 19 2008 lnussel@suse.de
- set Required-Stop in init script
* Thu Jun 26 2008 lnussel@suse.de
- fix build of hw_i2cuser on 11.0+ (bnc#387587)
* Wed May  7 2008 lnussel@suse.de
- fix build
- BuildRequire linux-kernel-headers and libusb-devel to enable
  additional userspace drivers
* Mon May  5 2008 lnussel@suse.de
- new version 0.8.3
  * added support for Samsung USB IR Receiver (Robert Schedel)
  * added support for Soundgraph iMON IR/LCD (Dean Harding)
  * added support for IRLink receiver (Maxim Muratov)
  * added support for VLSystem MPlay Blast (Benoit Laurent)
  * implemented SIMULATE command in irsend to simulate IR events
  * added user-space I2C driver (Adam Sampson)
  * added support for Hauppauge HVR-1300 (Jan Frey)
  * dropped support for 2.4 kernels
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Feb 21 2008 crrodriguez@suse.de
- add missing insserv_prereq
- add missing calls to restart_on_update and stop_on_removal macros
* Fri Aug 10 2007 lnussel@suse.de
- upgrade to 0.8.2 final, just minor changes
* Thu Jun 21 2007 lnussel@suse.de
- require $remote_fs in init script (#285548)
* Fri Jun  1 2007 lnussel@suse.de
- update to 0.8.2pre3:
  * added support for TechnoTrend USB IR receiver (Stefan Macher)
  * automatic release event generation in lircd
  * added support for Apple Mac mini USB IR Receiver (Stephen Williams)
  * added support for ADSTech USBX-707 USB IR Blaster (Jelle Foks)
  * periodically try to reopen lirc device if reading fails (probably
    because USB device has been removed)
  * added support for Creative USB IR Receiver (SB0540) (Benjamin Drung)
  * lirc_mceusb2 supports setting carrier frequency
  * added support for Asus DH remote (Brice DUBOST, Bernhard
    Frauendienst)
  * fixed show-stopper bug in RC-6 transmit code
  * added support for Kanam Accent (Niccolo Rigacci)
  * added support for SoundGraph iMON 2.4G DT & LT (Morten Bogeskov)
* Thu May 31 2007 lnussel@suse.de
- don't install useless contrib stuff
- add proper ldconfig and insserv calls
- make initscript to automatically install
  linux-input-layer-lircd.conf if lircd.conf doesn't exist and
  /dev/input/ir is used as device
- add  /etc/lircd.conf as %%ghost
- don't package /var/run/lirc/lircd
- don't package all remotes to save space
* Mon Apr 23 2007 hvogel@suse.de
- Add config for imon2 driver with missing keys and pad2key
  addidtion from M. Brakemeier
* Tue Jan 16 2007 lnussel@suse.de
- use optflags
* Thu Jan 11 2007 lnussel@suse.de
- new version 0.8.1
  * added support for USB-UIRT
  * added transmitter support for new version of Windows Media
    Center transceiver
  * added support for Iguanaworks USB IR Transceiver
* Tue Nov 14 2006 lnussel@suse.de
- fix excessive logging in devinput driver, use syslog (#218286)
* Fri Nov 10 2006 ro@suse.de
- fix docu permissions
* Thu Aug 24 2006 lnussel@suse.de
- SYSFS{../name} is deprecated, use ATTRS{name} instead
* Thu Aug 17 2006 ro@suse.de
- fix build with 2.6.18 (from cvs)
* Tue Feb  7 2006 lnussel@suse.de
- remove CFT2000 config file as it contains a strange proprietary
  notice (#148744)
* Thu Feb  2 2006 lnussel@suse.de
- update to version 0.8.0
  * included kernel modules build with minor modifications (#147601)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 ro@suse.de
- added (empty) rest of LSB init script header
* Wed Nov 30 2005 lnussel@suse.de
- use different way for matching *IR* in 51-lirc.rules to get rid of
  udev.get_input_lirc.sh
* Thu Sep  1 2005 lnussel@suse.de
- move lirc related udev stuff into lirc package (#114656)
- improve checks for device presence in init script to avoid
  starting an unconfigured lircd that just silently quits later.
  (#106055)
- remove dependencies from initscript to allow vdr to start earlier
* Mon Aug 29 2005 lnussel@suse.de
- update input layer config file (#113852)
* Tue Aug 16 2005 lnussel@suse.de
- don't fail if evdev is not available as module (#104558)
* Wed Aug 10 2005 kraxel@suse.de
- fix quoting bug in init script (#102540).
* Tue May 31 2005 kraxel@suse.de
- fix init script (#86271).
- updfate to version 0.7.1
* Fri Mar 11 2005 lnussel@suse.de
- check if /dev/lircd is already a symlink before creating it (#71063)
- don't unload module when stopping lirc (#71063)
* Tue Mar  1 2005 kraxel@suse.de
- add compatibility symlink (bug #67039).
* Mon Jan 24 2005 kraxel@suse.de
- update to 0.7.0 final.
- move lircd sockets from /dev to /var/run/lirc (bug #44254).
* Fri Aug 20 2004 kraxel@suse.de
- update to cvs [2004-08-20]
* Tue Mar 30 2004 kraxel@suse.de
- add README.SUSE file (by lnussel)
- remove some files non-text files from documentation (bug #36349).
* Fri Mar 12 2004 kraxel@suse.de
- fix lirc start script.
* Mon Mar  8 2004 kraxel@suse.de
- update to cvs [2004-03-08]
- dropped global config file patch (merged into cvs).
* Fri Mar  5 2004 kraxel@suse.de
- update to cvs [2004-03-05]
- init script fixes.
* Mon Mar  1 2004 kraxel@suse.de
- update to cvs [2004-03-01]
- added input-layer-lircd.conf
- added global config file patch (by msvec@suse.cz).
* Thu Feb  5 2004 kraxel@suse.de
- drop km_lirc.
* Mon Jan 19 2004 kraxel@suse.de
- updated to cvs snapshot again [2004-01-16].
* Tue Oct 21 2003 kraxel@suse.de
- updated to 0.7.0 cvs snapshot.
* Thu Aug 14 2003 kraxel@suse.de
- Respect INSTALL_MOD_PATH.
* Thu Aug 14 2003 kraxel@suse.de
- added ServiceRestart to sysconfig.lirc (#28893).
* Thu Aug 14 2003 kraxel@suse.de
- fix i2c kernel module build failure.
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directory to filelist
* Wed Mar 12 2003 kraxel@suse.de
- added metadata to sysconfig template [bugzilla #25077]
* Mon Mar 10 2003 kraxel@suse.de
- added init script for lircd [bugzilla #24787]
* Thu Mar  6 2003 schwab@suse.de
- Fix invalid use of floating point in kernel.
* Mon Mar  3 2003 kraxel@suse.de
- fixed module install failure (bug #24512).
* Wed Dec 11 2002 kraxel@suse.de
- splitted up the patch.
- minor specfile tweaks.
* Tue Oct 22 2002 uli@suse.de
- update -> 0.6.6 (rc tool for sending IR commands, bugfix for
  Winfast TV2000 card, SIR support for Actisys Act200L dongle,
  support for hardware connected to soundcard input, added support
  for Tekram M230 Mach64)
* Mon Jun  3 2002 uli@suse.de
- added fix for drivers using std serial device by werner@suse.de
- touch all files to same date to avoid automake rerun
* Sun Apr 28 2002 schwab@suse.de
- Fix to build with 2.4.19-pre7.
* Fri Feb 22 2002 uli@suse.de
- removed many unnecessary files from km_lirc (fixes bug #13733)
* Mon Jan 28 2002 uli@suse.de
- update -> 0.6.5 (support for additional IR reveivers, bugfixes)
* Tue Sep  4 2001 uli@suse.de
- added remotes tarball from lirc.org containing configs for a few
  hundred remote controls
* Tue Aug 21 2001 lnussel@suse.de
- new version 0.6.4 (bugfix release)
- cleaned up spec file, now uses buildroot
- added example config files for remotes to %%doc
- re-enabled parallel port driver
- changed --with-driver=none to =any to make lircd actually use
  remote hardware instead of switching into network only mode
  (fixes Bug #9655)
* Sat May 12 2001 schwab@suse.de
- Fix missing declarations.
* Wed May  9 2001 uli@suse.de
- building lirc_dev module in Makefile.module (reqd. by lirc_i2c)
* Thu Apr 26 2001 uli@suse.de
- fixed Makefile.module, configure call for building with
  "--with-driver=none"
- disabled parport module (no go with 2.4.3)
* Thu Apr  5 2001 uli@suse.de
- kernel sources not needed any more
* Mon Mar 19 2001 uli@suse.de
- building lirc_i2c module in Makefile.module
* Mon Mar 19 2001 uli@suse.de
- update -> 0.6.3 final
- added suse_update_config before configure (fixes IA64)
- disabled useless building of drivers
- fixed building of shared libs
* Thu Feb 22 2001 uli@suse.de
- added -I/usr/src/linux/include to kernel module Makefiles
* Wed Feb  7 2001 uli@suse.de
- added lx_suse to neededforbuild
* Fri Jan 12 2001 uli@suse.de
- update -> 0.6.3pre3 (needed for kernels 2.2.18 and 2.4.0)
* Tue Oct 10 2000 ro@suse.de
- fixed oldconfig
* Mon Oct  9 2000 kukuk@suse.de
- Use default values for make oldconfig
* Fri Sep 15 2000 uli@suse.de
- fixed location of config file (/usr/etc -> /etc)
* Fri Sep 15 2000 uli@suse.de
- fixed Makefile.module
* Wed Sep 13 2000 uli@suse.de
- initial package
